﻿using UnityEngine;
using System.Collections;

public class HeightFogDensityMod : MonoBehaviour
{
	public float maxDensity = 1.0f;
	public float fogStartHeight = -1.0f;
	public float fogMaxThicknessHeight = -10.0f;
	public Color fogColor;
	public GameObject trackedObject;

	private Camera[] affectedCameras;
	private float startDensity;
	private Color camBgStartColor;
	private Color currentCamBgColor;

	void Start()
	{
		affectedCameras = trackedObject.GetComponentsInChildren<Camera>();
		startDensity = RenderSettings.fogDensity;

		camBgStartColor = affectedCameras[0].backgroundColor;
	}
	
	void Update()
	{
		float theCurrentHeight = trackedObject.transform.position.y;

		if( theCurrentHeight < fogStartHeight )
		{
			float theFogPercentage = ( fogStartHeight - theCurrentHeight ) / ( fogStartHeight - fogMaxThicknessHeight );
			currentCamBgColor = Color.Lerp( camBgStartColor, fogColor, theFogPercentage );
			UpdateCamerasBgColor( currentCamBgColor );

			float theNewFogDensity = maxDensity * theFogPercentage * theFogPercentage;
			theNewFogDensity = Mathf.Max( startDensity, theNewFogDensity );
			RenderSettings.fogDensity = theNewFogDensity;
			RenderSettings.fogColor = currentCamBgColor;
		}
		else if( currentCamBgColor != camBgStartColor )
		{
			currentCamBgColor = camBgStartColor;
			UpdateCamerasBgColor( currentCamBgColor );
			RenderSettings.fogDensity = startDensity;
			RenderSettings.fogColor = camBgStartColor;
		}
	}

	private void UpdateCamerasBgColor( Color aColor )
	{
		foreach( Camera theCamera in affectedCameras )
		{
			theCamera.backgroundColor = aColor;
		}
	}
}
