﻿using UnityEngine;
using System.Collections;

public class LaserBeam : MonoBehaviour
{
	public Transform aimTransform;
	public Transform scaledBeamTransform; //scale local z to make laser longer.
	public Light endLight;
	public float maxLength = 200.0f;

	// Update is called once per frame
	void Update()
	{
		PlayerLogic theHitPlayer = null;
		float thePlayerHitDist = 5000.0f;

		float theLaserLength = maxLength;
		RaycastHit[] theHits = Physics.RaycastAll( transform.position, aimTransform.position - transform.position, maxLength );
		foreach( RaycastHit theHit in theHits )
		{
			PlayerLogic thePlayer = theHit.collider.gameObject.GetComponent<PlayerLogic>();
			if( thePlayer )
			{
				theHitPlayer = thePlayer;
				thePlayerHitDist = theHit.distance;
			}
			else if( theHit.distance < theLaserLength &&
			    theHit.collider.gameObject.layer != 8 && //screen dimension layer
			    !theHit.collider.gameObject.GetComponent<KillPlayerOnHit>() )
			{
				theLaserLength = theHit.distance;
			}
		}

		Vector3 theBeamScale = scaledBeamTransform.localScale;
		theBeamScale.z = theLaserLength;
		scaledBeamTransform.localScale = theBeamScale;

		endLight.transform.localPosition = new Vector3( 0, 0, 0.1f - theLaserLength );
		if( theLaserLength < maxLength )
		{
			endLight.enabled = true;
		}
		else
		{
			endLight.enabled = false;
		}

		//hax because ColliderDidEnter won't get called if the player ain't moving.
		if( theHitPlayer && theLaserLength > thePlayerHitDist )
		{
			theHitPlayer.Die();
		}
	}
}
