﻿using UnityEngine;
using System.Collections;

public class ScreenObject : MonoBehaviour
{
	public Renderer[] showOnHoverRenderers;
	public Collider[] activatedColliders;
	public Rigidbody[] activatedRigidbodies;
	public Material deactivatedMaterial;
	public Material activatedMaterial;
	public TextMesh hoverText;
	public bool startActive = false;

	private bool isHovered;
	private bool isActivated;
	private float unhoverTime;

	void Start()
	{
		unhoverTime = -5000.0f;
		Unhover();

		if( startActive )
		{
			Activate();
		}
		else
		{
			Deactivate();
		}
	}

	void Update()
	{
		if( unhoverTime >= 0 && Time.time > unhoverTime )
		{
			Unhover();
		}
	}

	public void ToggleActivate()
	{
		if( !isActivated )
		{
			Activate();
		}
		else
		{
			Deactivate();
		}
	}
	
	private void Activate()
	{
		foreach( Collider theCollider in activatedColliders )
		{
			theCollider.isTrigger = false;
		}

		foreach( Rigidbody theBody in activatedRigidbodies )
		{
			theBody.isKinematic = false;
			theBody.useGravity = true;
		}

		renderer.material = activatedMaterial;
		hoverText.text = "deactivate";
		isActivated = true;
		gameObject.layer = 1; // "Default" layer

		SendMessage( "ScreenObjectActivated", SendMessageOptions.DontRequireReceiver );
	}

	private void Deactivate()
	{
		foreach( Collider theCollider in activatedColliders )
		{
			theCollider.isTrigger = true;
		}
		
		foreach( Rigidbody theBody in activatedRigidbodies )
		{
			theBody.isKinematic = true;
			theBody.useGravity = false;
		}

		renderer.material = deactivatedMaterial;
		hoverText.text = "activate";
		isActivated = false;
		gameObject.layer = 8; // "Screen Dimension" layer

		SendMessage( "ScreenObjectDeactivated", SendMessageOptions.DontRequireReceiver );
	}

	public void UpdateHover()
	{
		if( !isHovered )
		{
			foreach( Renderer theRenderer in showOnHoverRenderers )
			{
				theRenderer.enabled = true;
			}
			isHovered = true;
		}

		unhoverTime = Time.time + 0.1f;
	}

	private void Unhover()
	{
		foreach( Renderer theRenderer in showOnHoverRenderers )
		{
			theRenderer.enabled = false;
		}
		isHovered = false;
		unhoverTime = -5000.0f;
	}

	public bool IsActivated()
	{
		return isActivated;
	}
}
